Module basic

Module basic 

Modules

compression

Functions

from_path
Open a possibly compressed file and decompress it transparently.
get_reader
Create a readable stream that can be read transparently even if the original stream is compress. Also returns the compression type of the original stream.
get_writer
Create a new writable stream with the given compression format and level.
sniff
Finds out what is the compression format for a stream based on magic numbers (the first few bytes of the stream).
to_path
Create a file with specific compression format.