Module basic
niffler_
temp
2.7.1
Module basic
Module Items
Modules
Functions
In crate niffler_
temp
niffler_temp
Module
basic
Modules

compression
Functions

from_
path
Open a possibly compressed file and decompress it transparently.
get_
reader
Create a readable stream that can be read transparently even if the original stream is compress. Also returns the compression type of the original stream.
get_
writer
Create a new writable stream with the given compression format and level.
sniff
Finds out what is the compression format for a stream based on magic numbers (the first few bytes of the stream).
to_path
Create a file with specific compression format.